@@ -3,9 +3,11 @@
 #' @export
 #'
 #' @param dataset Dataset name. Required.
-#' @param limit (numeric) Number of rows of the dataset to return. Default: 50
+#' @param limit (numeric) Number of rows of the dataset to return. Default (and max): 500
 #' @param select (character) Vector of columns to be returned with each row. Default is to return
 #' all columns.
+#' @param conjunction one of "and" or "or". Only applicable when more than one \code{search}
+#' or \code{where} parameter is provided. Default: "and"
 #' @param sort (character) Sort rows by a particular column in a given direction. + denotes
 #' ascending order, - denotes descending. See examples.
 #' @param page (numeric) Paginate row results and return the nth page of results. Pages are
@@ -41,10 +43,12 @@
 #' enigma_data(dataset='us.gov.whitehouse.visitor-list', where='total_people > 5')
 #'
 #' # White house visitor list - search for Vitale in full name field
-#' enigma_data(dataset='us.gov.whitehouse.visitor-list', search='@@namefull=Vitale')
+#' ## remove the 2nd at symbol before running
+#' # enigma_data(dataset='us.gov.whitehouse.visitor-list', search='@@namefull=Vitale')
 #'
 #' # White house visitor list - search for SOPHIA in first name field
-#' enigma_data(dataset='us.gov.whitehouse.visitor-list', search='@@namefirst=SOPHIA')
+#' ## remove the 2nd at symbol before running
+#' # enigma_data(dataset='us.gov.whitehouse.visitor-list', search='@@namefirst=SOPHIA')
 #'
 #' # Domestic Market Flight Statistics (Final Destination)
 #' dataset='us.gov.dot.rita.trans-stats.air-carrier-statistics.t100d-market-all-carrier'
@@ -53,18 +57,26 @@
 #' # Search for 'apple' in the Crunchbase dataset, and get two columns back
 #' enigma_data(dataset='com.crunchbase.info.companies.acquisition', search='apple',
 #' select=c('acquisition','price_amount'))
+#'
+#' # conjunction parmeter, compare these two queries
+#' enigma_data(dataset = 'us.gov.dol.ogesdw.msha.msha-accident',
+#'    where = c('degree_injury_cd > 2', 'no_injuries > 1'), conjunction = "and")
+#' enigma_data(dataset = 'us.gov.dol.ogesdw.msha.msha-accident',
+#'    where = c('degree_injury_cd > 2', 'no_injuries > 1'), conjunction = "or")
 #' }
 
-enigma_data <- function(dataset=NULL, limit=50, select=NULL, sort=NULL, page=NULL, where=NULL,
-                        search=NULL, key=NULL, ...)
-{
+enigma_data <- function(dataset=NULL, limit=500, select=NULL, conjunction=NULL,
+                        sort=NULL, page=NULL, where=NULL, search=NULL, key=NULL, ...) {
+
   key <- check_key(key)
   check_dataset(dataset)
-  if(!is.null(select)) select <- paste(select, collapse = ",")
+  if (!is.null(select)) select <- paste(select, collapse = ",")
 
   url <- sprintf('%s/data/%s/%s', en_base(), key, dataset)
-  args <- engigma_compact(list(limit=limit, select=select, sort=sort, page=page,
-                               where=where, search=search))
+  sw <- proc_search_where(search, where)
+  args <- list(limit = limit, select = select, conjunction = conjunction,
+                               sort = sort, page = page)
+  args <- as.list(unlist(ec(c(sw, args))))
   json <- enigma_GET(url, args, ...)
   meta <- json$info
   json$result <- lapply(json$result, as.list)
@@ -72,5 +84,32 @@ enigma_data <- function(dataset=NULL, limit=50, select=NULL, sort=NULL, page=NUL
                   lapply(json$result, function(x){
                     x[sapply(x, is.null)] <- NA; data.frame(x, stringsAsFactors = FALSE)
                   }))
-  structure(list(success = json$success, datapath = json$datapath, info = meta, result = dat2), class="enigma")
+  structure(list(success = json$success, datapath = json$datapath, info = meta, result = dat2),
+            class = "enigma", dataset = dataset)
+}
+
+#' @export
+print.enigma <- function(x, ..., n = 10) {
+  cat("<<enigma data>>", sep = "\n")
+  cat(paste0("  Dataset: ", attr(x, "dataset")), sep = "\n")
+  cat(paste0("  Found/returned: ", sprintf("[%s/%s]", x$info$total_results, NROW(x$result))), "\n", sep = "\n")
+  trunc_mat(x$result, n = n)
+}
+
+proc_search_where <- function(x, y) {
+  if (!is.null(x)) {
+    if (length(x) > 1) {
+      x <- lapply(x, function(z) list(search = z))
+    } else {
+      x <- list(search = x)
+    }
+  }
+  if (!is.null(y)) {
+    if (length(y) > 1) {
+      y <- lapply(y, function(z) list(where = z))
+    } else {
+      y <- list(where = y)
+    }
+  }
+  c(x, y)
 }
