@@ -11,18 +11,15 @@
 #' rate_limit()
 #' }
 
-rate_limit <- function(key=NULL, ...)
-{
+rate_limit <- function(key=NULL, ...) {
   key <- check_key(key)
   url <- sprintf('%s/limits/%s', en_base(), key)
-  json <- enigma_GET(url, list(), ...)
-  json$seconds_remaining <-  as.POSIXct(as.integer(json$seconds_remaining), tz = "UTC", origin = "1970-01-01")
-  structure(json, class="enigma_rate")
+  json <- enigma_GET(url, NULL, ...)
+  structure(json, class = "enigma_rate")
 }
 
 #' @export
-print.enigma_rate <- function (x, ...)
-{
+print.enigma_rate <- function(x, ...) {
   cat("Period: ", x$period, "\n", sep = "")
   cat("Rate limit: 5000", "\n", sep = "")
   cat("Remaining - data:  ", x$data, "\n", sep = "")
@@ -31,14 +28,13 @@ print.enigma_rate <- function (x, ...)
   cat("Resets in:  ", time(x$seconds_remaining), "\n", sep = "")
 }
 
-time <- function (x)
-{
+time <- function(x) {
   x <- as.integer(x)
   if (x > 3600) {
-    paste0(x%/%3600, " hours")
+    paste0(x %/% 3600, " hours")
   }
   else if (x > 300) {
-    paste0(x%/%60, " minutes")
+    paste0(x %/% 60, " minutes")
   }
   else if (x > 60) {
     paste0(round(x/60, 1), " minutes")
